@@ -360,6 +360,20 @@ fromExtension e = case e of
   TH.TypeData                          -> Nothing
 #endif
 
+-- 2.21.0 ---------------------------------------
+
+#if MIN_VERSION_template_haskell(2,21,0)
+  TH.TypeAbstractions                  -> Nothing
+  TH.ExtendedLiterals                  -> Nothing
+#endif
+
+-- 2.22.0 ---------------------------------------
+
+#if MIN_VERSION_template_haskell(2,22,0)
+  TH.RequiredTypeArguments             -> Nothing
+  TH.ListTuplePuns                     -> Nothing
+#endif
+
   -- NB: when adding a case here, you may also need to update `toExtension`
 
 
